@@ -5,7 +5,7 @@ use warnings;
 use Wasm::Wasmtime;
 
 my $store = Wasm::Wasmtime::Store->new;
-my $module = Wasm::Wasmtime::Module->new( $store, wat => q{
+my $module = Wasm::Wasmtime::Module->new( $store->engine, wat => q{
   (module
     (func $hello (import "" "hello"))
     (func (export "run") (call $hello))
