@@ -6,7 +6,7 @@ use Wasm::Wasmtime;
 use PeekPoke::FFI qw( peek poke );
 
 my $wasm_store = Wasm::Wasmtime::Store->new;
-my $module = Wasm::Wasmtime::Module->new( $wasm_store, file => path(__FILE__)->parent->child('memory.wat') );
+my $module = Wasm::Wasmtime::Module->new( $wasm_store->engine, file => path(__FILE__)->parent->child('memory.wat') );
 my $instance = Wasm::Wasmtime::Instance->new($module, $wasm_store);
 
 my $memory = $instance->exports->memory;
